==> hs-DeepArrow-0.3.3_2.tbz: lib/ghc-7.0.3/cabal/DeepArrow-0.3.3/register.sh <==
#!/bin/sh
echo 'name: DeepArrow
version: 0.3.3
id: DeepArrow-0.3.3-efd8ecabddaf5691fd7095c1cfa33d28

license: BSD3
copyright: (c) 2007,2009 by Conal Elliott
maintainer: conal@conal.net
stability: experimental
homepage: http://haskell.org/haskellwiki/DeepArrow
package-url: http://darcs.haskell.org/packages/DeepArrow
description: This library provides a framework for type-directed composition of value
             editors (non-syntactic transformations).  The tools enable \"deep function
             application\" in two senses: deep application of functions and
             application of deep functions.  These tools generalize beyond values and
             functions, via the @DeepArrow@ subclass of the @Arrow@ type class.
             .
             For more information see:
             .
             * The project wiki page <http://haskell.org/haskellwiki/DeepArrow>
             .
             * Application of deep arrows for composable interfaces in the TV library:
             <http://haskell.org/haskellwiki/TV>
             .
             * The motivating idea and paper "Tangible Functional Programming":
             <http://conal.net/papers/Eros>
             .
             This page and the module documentation pages have links to colorized
             source code and to wiki pages where you can read and contribute /user
             comments/.  Enjoy!
             .
             The primary module is "Control.Arrow.DeepArrow".  Examples in
             "Control.Arrow.DeepArrow.Examples".
             .
             /Note/: Many of the type signatures use infix type operators (as in
             @a~>b@), a recent extension to GHC.  In reading the documentation and
             code, be aware that infix operators bind more tightly than @->@.
             .
             &#169; 2007 by Conal Elliott (<http://conal.net>); BSD3 license.
category: Combinators, Control
author: Conal Elliott <conal@conal.net>
exposed: True
exposed-modules: Control.Arrow.DeepArrow Data.FunArr
                 Data.DDeepArrow Language.Haskell.ToHs Language.Haskell.Parens
                 Control.Arrow.DeepArrow.Examples
hidden-modules:
import-dirs: /usr/local/lib/ghc-7.0.3/cabal/DeepArrow-0.3.3
library-dirs: /usr/local/lib/ghc-7.0.3/cabal/DeepArrow-0.3.3
              /usr/local/lib
hs-libraries: HSDeepArrow-0.3.3
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: TypeCompose-0.8.3-c908fdbf8c63e91b72a3f12d10a425fa
         base-4.3.1.0-93a63ba911a7eac625848432374f7fee
         haskell-src-1.0.1.4-7428a8c9049cd6bf5abdc0bbd2d417c5
         mtl-2.0.1.0-9763a8821c812a910d327bad2c0d23b2
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.3/cabal/DeepArrow-0.3.3/html/DeepArrow.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.3/cabal/DeepArrow-0.3.3/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-DeepArrow-0.3.5.tbz: lib/ghc-7.0.4/cabal/DeepArrow-0.3.5/register.sh <==
#!/bin/sh
echo 'name: DeepArrow
version: 0.3.5
id: DeepArrow-0.3.5-1032fcc2ba89984f3992008bf2166583

license: BSD3
copyright: (c) 2007-2012 by Conal Elliott
maintainer: conal@conal.net
stability: experimental
homepage: http://haskell.org/haskellwiki/DeepArrow
package-url: http://code.haskell.org/~conal/code/DeepArrow
description: This library provides a framework for type-directed composition of value
             editors (non-syntactic transformations).  The tools enable \"deep function
             application\" in two senses: deep application of functions and
             application of deep functions.  These tools generalize beyond values and
             functions, via the @DeepArrow@ subclass of the @Arrow@ type class.
             .
             For more information see:
             .
             * The project wiki page <http://haskell.org/haskellwiki/DeepArrow>
             .
             * Application of deep arrows for composable interfaces in the TV library:
             <http://haskell.org/haskellwiki/TV>
             .
             * The motivating idea and paper "Tangible Functional Programming":
             <http://conal.net/papers/Eros>
             .
             The primary module is "Control.Arrow.DeepArrow".  Examples in
             "Control.Arrow.DeepArrow.Examples".
             .
             /Note/: Many of the type signatures use infix type operators (as in
             @a~>b@).  In reading the documentation and code, be aware that infix
             operators bind more tightly than @->@.
             .
             &#169; 2007-2012 by Conal Elliott (<http://conal.net>); BSD3 license.
category: Combinators, Control
author: Conal Elliott <conal@conal.net>
exposed: True
exposed-modules: Control.Arrow.DeepArrow Data.FunArr
                 Data.DDeepArrow Language.Haskell.ToHs Language.Haskell.Parens
                 Control.Arrow.DeepArrow.Examples
hidden-modules:
import-dirs: /usr/local/lib/ghc-7.0.4/cabal/DeepArrow-0.3.5
library-dirs: /usr/local/lib/ghc-7.0.4/cabal/DeepArrow-0.3.5
              /usr/local/lib
hs-libraries: HSDeepArrow-0.3.5
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: TypeCompose-0.9.1-5144063d89ec59921af0cf8c4d8a9b13
         base-4.3.1.0-c683e1c476645dcbab1b168f8e5a9aeb
         haskell-src-1.0.1.4-dc61c7768722cce3fbdb0ab453832c56
         mtl-2.0.1.0-91f62d81c946aa60137dcc008e554a3a
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.4/cabal/DeepArrow-0.3.5/html/DeepArrow.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.4/cabal/DeepArrow-0.3.5/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
